@@ -22,8 +22,6 @@
 #' @param ageGroup A list of age groups to stratify results by.
 #' @param sex Boolean variable. Whether to stratify by sex (TRUE) or not
 #' (FALSE).
-#' @param sample An integer to sample the tables to only that number of records.
-#' If NULL no sample is done.
 #' @param dateRange A list containing the minimum and the maximum dates
 #' defining the time range within which the analysis is performed.
 #' @return A summarised_result object.
@@ -57,7 +55,6 @@ summariseClinicalRecords <- function(cdm,
                                      typeConcept = TRUE,
                                      sex = FALSE,
                                      ageGroup = NULL,
-                                     sample = NULL,
                                      dateRange = NULL) {
   # Initial checks ----
   cdm <- omopgenerics::validateCdmArgument(cdm)
@@ -78,7 +75,7 @@ summariseClinicalRecords <- function(cdm,
   omopgenerics::assertLogical(typeConcept, length = 1)
   omopgenerics::assertLogical(sex, length = 1)
   ageGroup <- omopgenerics::validateAgeGroupArgument(ageGroup, multipleAgeGroup = FALSE)
-  omopgenerics::assertNumeric(sample, integerish = TRUE, min = 1, null = TRUE, length = 1)
+
 
   # warnings for observation_period
   warnStandardConcept <- standardConcept & !missing(standardConcept)
